Crate inline_string

Crate inline_string 

inline_string

This crate provides a string type backed by an inline array of bytes.

Features

You can enable the following cargo features for ecosystem trait implementations:

  • serde implements serde_core::Serialize and serde_core::Deserialize.
  • sqlx implements sqlx::Type, sqlx::Encode, and sqlx::Decode.

All features are disabled by default.

Structs

InlineString
An array-backed string.